.. Copyright (C) 2018-2019 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2018-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.backup2l`` role manages the `backup2l`__ (backup tool) script.
This script can be used to make automated, incremental archives of a given host
which can be copied to another system as a backup.

.. __: https://github.com/gkiefer/backup2l
